@@ -1,9 +1,10 @@
-"""Dates and times.
+"""Dates and times
 
 This is an extension of :mod:`datetime`.
 
 """
 
+__version__ = "0.2.2"
 __copyright__ = "Copyright (C) 2014 Ivan D Vasin"
 __credits__ = ["Ivan D Vasin"]
 __maintainer__ = "Ivan D Vasin"
